You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@iotdb.apache.org by ja...@apache.org on 2022/03/16 08:47:07 UTC

[iotdb] branch mpp-ty created (now 6237d9a)

This is an automated email from the ASF dual-hosted git repository.

jackietien pushed a change to branch mpp-ty
in repository https://gitbox.apache.org/repos/asf/iotdb.git.


      at 6237d9a  add setNoMoreTsBlocks(), close() and abort() methods in SinkHandle interface

This branch includes the following new commits:

     new 6237d9a  add setNoMoreTsBlocks(), close() and abort() methods in SinkHandle interface

The 1 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


[iotdb] 01/01: add setNoMoreTsBlocks(), close() and abort() methods in SinkHandle interface

Posted by ja...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

jackietien pushed a commit to branch mpp-ty
in repository https://gitbox.apache.org/repos/asf/iotdb.git

commit 6237d9a5ccb3ce30055e8537ffe8e7eb456e76ab
Author: JackieTien97 <ja...@gmail.com>
AuthorDate: Wed Mar 16 16:46:10 2022 +0800

    add setNoMoreTsBlocks(), close() and abort() methods in SinkHandle interface
---
 .../org/apache/iotdb/db/mpp/buffer/SinkHandle.java  | 21 ++++++++++++++++++---
 1 file changed, 18 insertions(+), 3 deletions(-)

diff --git a/server/src/main/java/org/apache/iotdb/db/mpp/buffer/SinkHandle.java b/server/src/main/java/org/apache/iotdb/db/mpp/buffer/SinkHandle.java
index e80550f..0c78196 100644
--- a/server/src/main/java/org/apache/iotdb/db/mpp/buffer/SinkHandle.java
+++ b/server/src/main/java/org/apache/iotdb/db/mpp/buffer/SinkHandle.java
@@ -28,14 +28,29 @@ public interface SinkHandle {
   ListenableFuture<Void> isFull();
 
   /**
    * Sends a tsBlock to an unpartitioned buffer. If no-more-pages has been set, the send tsBlock
    * call is ignored. This can happen with limit queries.
    */
   void send(ByteBuffer tsBlock);
 
   /**
    * Sends a tsBlock to a specific partition. If no-more-pages has been set, the send tsBlock call
    * is ignored. This can happen with limit queries.
    */
   void send(int partition, ByteBuffer tsBlock);
+
+  /**
+   * Notify SinkHandle that no more tsBlocks will be sent. Any future calls to send a tsBlock are
+   * ignored.
+   */
+  void setNoMoreTsBlocks();
+
+  /** close the sink handle, discarding all tsBlocks which may still in memory buffer. */
+  void close();
+
+  /**
+   * Abort the sink handle, discarding all tsBlocks which may still in memory buffer, but blocking
+   * readers. It is expected that readers will be unblocked when the failed query is cleaned up.
+   */
+  void abort();
 }
@@ -28,14 +28,29 @@ public interface SinkHandle {
 
   /**
-   * Sends a tsBlock to an unpartitioned buffer. If no-more-pages has been set, the send tsBlock
+   * Sends a tsBlock to an unpartitioned buffer. If no-more-tsBlocks has been set, the send tsBlock
    * call is ignored. This can happen with limit queries.
    */
@@ -28,14 +28,29 @@ public interface SinkHandle {
 
   /**
-   * Sends a tsBlock to a specific partition. If no-more-pages has been set, the send tsBlock call
-   * is ignored. This can happen with limit queries.
+   * Sends a tsBlock to a specific partition. If no-more-tsBlocks has been set, the send tsBlock
+   * call is ignored. This can happen with limit queries.
    */
   void send(int partition, ByteBuffer tsBlock);